@@ -203,10 +203,10 @@ CV_HIST_ARRAY
 CV_HIST_SPARSE
 CV_HLS2BGR
 CV_HLS2RGB
+CV_HOUGH_GRADIENT
+CV_HOUGH_MULTI_SCALE
 CV_HOUGH_PROBABILISTIC
 CV_HOUGH_STANDARD
-CV_HOUGH_MULTI_SCALE
-CV_HOUGH_GRADIENT
 CV_HSV2BGR
 CV_HSV2RGB
 CV_INPAINT_NS
@@ -314,6 +314,12 @@ CV_THRESH_OTSU
 CV_THRESH_TOZERO
 CV_THRESH_TOZERO_INV
 CV_THRESH_TRUNC
+CV_TM_CCOEFF
+CV_TM_CCOEFF_NORMED
+CV_TM_CCORR
+CV_TM_CCORR_NORMED
+CV_TM_SQDIFF
+CV_TM_SQDIFF_NORMED
 CV_WARP_FILL_OUTLIERS
 CV_WARP_INVERSE_MAP
 CV_WINDOW_AUTOSIZE
@@ -338,19 +344,18 @@ IPL_ORIGIN_TL
 
     '2.001000' => [qw(
 
-CV_CALIB_ZERO_DISPARITY
 CV_CALIB_CB_FAST_CHECK
+CV_CALIB_ZERO_DISPARITY
 CV_CAP_PROP_EXPOSURE
 CV_CAP_PROP_RECTIFICATION
+CV_IMWRITE_JPEG_QUALITY
+CV_IMWRITE_PNG_COMPRESSION
+CV_IMWRITE_PXM_BINARY
 CV_WINDOW_FULLSCREEN
 CV_WINDOW_NORMAL
 CV_WND_PROP_AUTOSIZE
 CV_WND_PROP_FULLSCREEN
 
-CV_IMWRITE_JPEG_QUALITY
-CV_IMWRITE_PNG_COMPRESSION
-CV_IMWRITE_PXM_BINARY
-
 )],
 
     '2.002000' => [qw(
@@ -407,16 +412,16 @@ CV_YUV2RGB
 
     '2.003000' => [qw(
 
-CV_CAP_PROP_GAMMA
-CV_CAP_PROP_TRIGGER
-CV_CAP_PROP_TRIGGER_DELAY
 CV_CAP_PROP_AUTOGRAB
+CV_CAP_PROP_AUTO_EXPOSURE
+CV_CAP_PROP_GAMMA
+CV_CAP_PROP_MAX_DC1394
 CV_CAP_PROP_MONOCROME
 CV_CAP_PROP_SHARPNESS
-CV_CAP_PROP_MAX_DC1394
-CV_CAP_PROP_TEMPERATURE
-CV_CAP_PROP_AUTO_EXPOSURE
 CV_CAP_PROP_SUPPORTED_PREVIEW_SIZES_STRING
+CV_CAP_PROP_TEMPERATURE
+CV_CAP_PROP_TRIGGER
+CV_CAP_PROP_TRIGGER_DELAY
 CV_CAP_PROP_WHITE_BALANCE_BLUE_U
 CV_CAP_PROP_WHITE_BALANCE_RED_V
 
