@@ -5,11 +5,15 @@ package Cv::FileStorage;
 use 5.008008;
 use strict;
 use warnings;
+use Carp;
 
 BEGIN {
   Cv::aliases(
 	  [ 'cvWrite' ],
 	  [ 'cvGetFileNodeByName' ],
+	  [ 'Load' ],
+	  [ 'Read' ],
+	  [ 'ReadByName' ],
 	  );
 }
 
@@ -48,5 +52,9 @@ sub Read {
 	Bless(cvRead(@_));
 }
 
+sub ReadByName {
+	Bless(cvReadByName(@_));
+}
+
 1;
 __END__
